@@ -37,7 +37,7 @@ if ($ARGV[0] eq '-init'){
 	print "Check Detected: Now Checking File Sanity...\n";
 	&SysCheck;
 } else {
-	print "\n\nViperDB v0.9.3\n";
+	print "\n\nViperDB v0.9.4\n";
 	print "ERROR: Unrecognized option or none given.\n";
 	print "usage: ViperDB [-init|-check|-checkstrict] [-md5]\n";
 	print "     -init	  Initializes the ViperDB Databases\n";
@@ -190,7 +190,16 @@ sub CreateDB {
 					$bname=$files[$count];
 					$file="$wd/$bname";
 					if (! -d $file){
-						($dev, $ino, $mode, $nlink, $uid, $gid,$rdev, $size, $atime, $mtime, $ctime, $blksize, $blocks)= stat($file);
+						if ( -l $file) {
+							($dev, $ino, $mode, $nlink, $uid, $gid,$rdev, $size, $atime, $mtime, $ctime, $blksize, $blocks)= lstat($file);
+						} else {
+							($dev, $ino, $mode, $nlink, $uid, $gid,$rdev, $size, $atime, $mtime, $ctime, $blksize, $blocks)= stat($file);
+						}
+						if (1 == 0 && lc ($os_type) eq "linux" && -f $file) {
+							$attr = split / /, `lsattr \"$file\"`;
+						} else {
+							$attr = "--------";
+						}
 						my $digest = 0;
 						if ($domd5 == 1) {
 							$md5->reset;
@@ -201,6 +210,7 @@ sub CreateDB {
 								close (MD5F);
 							}
 						}
+						#print VIPERDB "$bname,$size,$mode,$uid,$gid,$mtime,$attr";
 						print VIPERDB "$bname,$size,$mode,$uid,$gid,$mtime";
 						if ($domd5 == 1) {
 							print VIPERDB ",$digest\n";
@@ -266,7 +276,9 @@ sub Compare {
 			chomp $fileinfob;
 			if($fileinfoa ne $fileinfob){
 				($a_bname,$a_size,$a_mode,$a_uid,$a_gid,$a_mtime,$a_md5) = split/,/,$fileinfoa;
+				#($a_bname,$a_size,$a_mode,$a_uid,$a_gid,$a_mtime,$a_attr,$a_md5) = split/,/,$fileinfoa;
 				($b_bname,$b_size,$b_mode,$b_uid,$b_gid,$b_mtime,$b_md5) = split/,/,$fileinfob;
+				#($b_bname,$b_size,$b_mode,$b_uid,$b_gid,$b_mtime,$b_attr,$b_md5) = split/,/,$fileinfob;
 				$myfile=$wd.$a_bname;
 				if(! defined($b_bname)){
 					print LOG "Alert - FILE DELETED: $mypath/$a_bname\n";
@@ -292,7 +304,7 @@ sub Compare {
 						}
 						if($a_perms ne $b_perms){
 							print LOG "Alert - PERMS: was $a_perms now $b_perms\n";
-							$errorsummary .= "Alert - PERMS: was $a_perms now $b_perms";
+							$errorsummary .= "Alert - PERMS: was $a_perms now $b_perms\n";
 							if($strictmode eq 'Y'){
 								print LOG "Alert - PERMS: Changing perms on $a_bname back to $a_perms\n";
 								$errorsummary .= "Alert - PERMS: Changing perms on $a_bname back to $a_perms\n";
@@ -308,6 +320,16 @@ sub Compare {
 							print LOG $string;
 							$errorsummary .= $string;
 						} # if
+						if(1 == 0 && $a_attr ne $b_attr){
+							print LOG "Alert - ATTR: was $a_attr now $b_attr\n";
+							$errorsummary .= "Alert - ATTR: was $a_attr now $b_attr\n";
+							# chattr unsupported yet... have to play with it a bit
+							if(1 == 0 && $strictmode eq 'Y' && lc ($os_type) eq "linux" ){
+								print LOG "Alert - ATTR: Changing attr on $a_bname back to $a_attr\n";
+								$errorsummary .= "Alert - ATTR: Changing attr on $a_bname back to $a_attr\n";
+								system ("chattr", "$a_attr", "$myfile");
+							} # if
+						} # if
 						if($domd5 == 1 && $a_md5 ne $b_md5){
 							print LOG "Alert - MD5: was $a_md5 now $b_md5\n";
 							$errorsummary .= "Alert - MD5: was $a_md5 now $b_md5\n";
